# MAVIS 交互式可视化分析工具

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mix-mavis)
![PyPI - License](https://img.shields.io/pypi/l/mix-mavis)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/mix-mavis)
[![Documentation Status](https://readthedocs.org/projects/mix-mavis/badge/?version=latest)](https://mix-mavis.readthedocs.io/zh/latest/?badge=latest)
![PyPI](https://img.shields.io/pypi/v/mix-mavis)


## 依赖包  
- ipython
- matplotlib
- seaborn
- ipywidgets
- boto3
- numpy
- pandas
- scipy
- scikit-learn
- torch

## 云服务器安装
`pip install mix-mavis`

## 平台
- AWS S3
- JUPYTER NOTEBOOK

## 数据分析
- [分析数据](http://52.82.119.95:8888/apps/analysis.ipynb)

## 数据交互
- [设置数据桶访问凭据](http://52.82.119.95:8888/apps/access.ipynb)  
- [获取实时MIXIOT数据](http://52.82.119.95:8888/apps/get_data.ipynb)    
- [导出MIXIOT历史数据](http://52.82.119.95:8888/apps/export.ipynb)  
- [数据上传至数据桶](http://52.82.119.95:8888/apps/upload.ipynb)  
- [从数据桶下载数据](http://52.82.119.95:8888/apps/download.ipynb)  
